@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2009 Index Data
+   Copyright (C) 2005-2010 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -64,6 +64,10 @@ BOOST_AUTO_TEST_CASE( test_filter_frontend_net_1 )
             mp::filter::FrontendNet nf;
         }
     }
+    catch (std::runtime_error &e) {
+        std::cerr << "std::runtime error: " << e.what() << std::endl;
+        BOOST_CHECK(false);
+    }
     catch ( ... ) {
         BOOST_CHECK (false);
     }
@@ -103,6 +107,10 @@ BOOST_AUTO_TEST_CASE( test_filter_frontend_net_2 )
             }
         }
     }
+    catch (std::runtime_error &e) {
+        std::cerr << "std::runtime error: " << e.what() << std::endl;
+        BOOST_CHECK(false);
+    }
     catch ( ... ) {
         BOOST_CHECK (false);
     }
@@ -134,6 +142,10 @@ BOOST_AUTO_TEST_CASE( test_filter_frontend_net_3 )
         }
         BOOST_CHECK(true);
     }
+    catch (std::runtime_error &e) {
+        std::cerr << "std::runtime error: " << e.what() << std::endl;
+        BOOST_CHECK(false);
+    }
     catch ( ... ) {
         BOOST_CHECK (false);
     }
